# Copyright 2016 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# == Class: tripleo::profile::base::memcached
#
# Memcached profile for tripleo
#
# === Parameters
#
# [*step*]
#   (Optional) The current step in deployment. See tripleo-heat-templates
#   for more details.
#   Defaults to hiera('step')
#
class tripleo::profile::base::memcached (
  $step = Integer(hiera('step')),
) {
  if $step >= 1 {
      include ::memcached

      # Automatic restart
      file { '/etc/systemd/system/memcached.service.d':
        ensure => directory,
        owner  => 'root',
        group  => 'root',
        mode   => '0755',
      }
      -> file { '/etc/systemd/system/memcached.service.d/memcached.conf':
        ensure  => file,
        owner   => 'root',
        group   => 'root',
        mode    => '0644',
        content => "[Service]\nRestart=always\n",
      }
      ~> exec { 'memcached-dropin-reload':
        command     => 'systemctl daemon-reload',
        refreshonly => true,
        path        => $::path,
      }
  }
}
